pub trait ForNetwork {
type Net: Network;
// Required methods
fn network(&self) -> Self::Net;
fn component(&self) -> &'static str;
}Expand description
Associates a type with a particular type of RPC networks, such as Ethereum or ZKsync Era. RPC traits created using jsonrpsee::rpc
can use ForNetwork as a client boundary to restrict which implementations can call their methods.